@@ -47,7 +47,7 @@ sub import {
 }
 
 
-our $VERSION = '0.0172';    # TRIAL VERSION
+our $VERSION = '0.0173';    # TRIAL VERSION
 
 1;
 
@@ -65,21 +65,39 @@ Evo - Perl Evo design pattern
 
 =head1 VERSION
 
-version 0.0172
+version 0.0173
 
 =head1 DESCRIPTION
 
-Tiny framework for organization non-trivial code into a simple logic.
-It includes benefits from functional and OO styles.
+This framowerk opens new age of perl programming
+It provides rewritten and postmodern features like
 
-Write fast, reusable and testable code.
+=over
 
-=head1 ATTENTION
+=item *
+Rewritten sexy L<Evo::Exporter>
 
-Attention. Don't use it right now. Wait for the stable release.
-Documentation is on it's way.
+=item *
+Post modern component oriented programming L<Evo::Comp> instead of OO
+
+=item *
+Fast Event-Loop L<Evo::Loop> with unique feature zones (Not ready)
+
+=item *
+Fast non recursive L<Evo::Promises>, 100% Promises/Spec A compatible
+
+=item *
+Interesting L<Evo::Realm> design pattern, which is as handy as "Singleton" but without Sintleton's flaws.
+It makes real thing that are considered impossible in other languages. For example, testing EventLoop timers without patching, separating flows for one loop and so on.
+(ready but experimental and not documented)
+
+=item *
+Exception handling in pure perl: L<Evo::Eval>, "try catch" alternative. Like C<Try::Tiny>, but without it's bugs and much faster
+
+=back
 
 =head1 IMPORTING
+
 Calls loads L<Evo::Eval> and calls it's C<import> method, emulating C<caller>.
 
   use Evo 'Evo::SomeComp';
