@@ -24,7 +24,16 @@ Evo::Default
 
 =head1 VERSION
 
-version 0.0172
+version 0.0173
+
+=head1 DESCRIPTION
+
+Enables default features and disable warnings for them
+
+=head1 SYNOPSYS
+
+  # strict, warnings, utf8, :5.20, postderef
+  use Evo;
 
 =head1 AUTHOR
 
