@@ -18,7 +18,25 @@ Evo::Loaded
 
 =head1 VERSION
 
-version 0.0172
+version 0.0173
+
+=head1 DESCRIPTION
+
+Mark module as loaded
+
+=head1 SYNOPSYS
+
+  package main;
+  use Evo;
+
+  {
+
+    package Foo;
+    use Evo -Loaded;
+  };
+
+  # now use can use this without "Can't find module..."
+  use Foo;
 
 =head1 AUTHOR
 
