@@ -20,7 +20,15 @@ Evo::Modern
 
 =head1 VERSION
 
-version 0.0172
+version 0.0173
+
+=head1 DESCRIPTION
+
+Enables features that I consider as usefull
+
+=head1 SYNOPSYS
+
+  use Evo -Modern;
 
 =head1 AUTHOR
 
