@@ -1,6 +1,6 @@
 package Evo::W::Eval;
 use Carp 'croak';
-use Evo '-Lib *', '-Export *';
+use Evo '-Eval *', '-Export *';
 
 
 sub w_eval_run : Export {
@@ -8,9 +8,10 @@ sub w_eval_run : Export {
   sub {
     my $next = shift;
     sub {
-      my ($res, $err) = eval_context_run(wantarray, @_, $next);
-      $catch->($err) if !$res;
-      return context_result($res);
+      my $call = eval_want(wantarray, @_, $next);
+      return $call->result if $call;
+      $catch->($@);
+      return;
     };
   };
 }
@@ -29,7 +30,7 @@ Evo::W::Eval
 
 =head1 VERSION
 
-version 0.0172
+version 0.0173
 
 =head1 AUTHOR
 
